@@ -792,7 +792,8 @@ parse_asx_entry (TotemPlParser *parser, char *base, xmlDocPtr doc,
 			continue;
 
 		/* ENTRY should only have one ref and one title nodes */
-		if (g_ascii_strcasecmp (node->name, "ref") == 0) {
+		if (g_ascii_strcasecmp (node->name, "ref") == 0
+				|| g_ascii_strcasecmp (node->name, "entryref") == 0) {
 			url = xmlGetProp (node, "href");
 			if (url == NULL)
 				url = xmlGetProp (node, "HREF");
@@ -844,6 +845,12 @@ parse_asx_entries (TotemPlParser *parser, char *base, xmlDocPtr doc,
 			if (parse_asx_entry (parser, base, doc, node) != FALSE)
 				retval = TRUE;
 		}
+		if (g_ascii_strcasecmp (node->name, "entryref") == 0) {
+			/* Found an entryref, give the parent instead of the
+			 * children to the parser */
+			if (parse_asx_entry (parser, base, doc, parent) != FALSE)
+				retval = TRUE;
+		}
 	}
 
 	return retval;
@@ -1100,7 +1107,7 @@ totem_pl_parser_add_directory (TotemPlParser *parser, const char *url,
 		}
 
 		str = g_build_filename (url, info->name, NULL);
-		if (strstr (str, "://") != NULL)
+		if (strstr (str, "://") != NULL && str[0] == '/')
 			fullpath = str + 1;
 		else
 			fullpath = str;
